@@ -1,8 +1,8 @@
 #' Elemental Graphic Display for Contrast Effect of ANOVA
-#' 
+#'
 #' Provides graphic displays that shows data and effects for a priori contrasts
 #' in ANOVA contexts; also corresponding numerical results.
-#' 
+#'
 #' Function provides graphic displays of contrast effects for prespecified
 #' contrasts in ANOVA. Data points are displayed as relevant for each contrast
 #' based on comparing groups according to the positive and negative contrast
@@ -26,7 +26,7 @@
 #' contrasts, at most G-1. If the number of columns of \code{contrasts} is G-1,
 #' then the number per group, or cell size, is taken to be
 #' \code{length(data)/G}, where \code{G = nrow(contrasts)}.
-#' 
+#'
 #' If the number of columns of \code{contrasts} is less than G-1 then the user
 #' must stipulate \code{npg}, the number in each group or cell.  The function
 #' is designed for the case when all cell sizes are the same, and may be most
@@ -41,7 +41,7 @@
 #' for all groups or cells in the design, where groups are simply numbered from
 #' 1:G, for G the number of groups, on the horizontal axis, versus the response
 #' values on the vertical axis.
-#' 
+#'
 #' @param data Vector of scores for all equally sized groups, or a data.fame or
 #'   matrix where each column represents a group.
 #' @param contrasts Matrix of column contrasts with dimensions (number of
@@ -51,21 +51,21 @@
 #'   graphic; defaults to a customized theme created for the contrast graphic
 #' @param print.four.plots.per.page If \code{TRUE}, the function lays out four plots per page and sends
 #'   each page to the graphics device. When running R interactively, you'll have an opportunity to review each page
-#'   before seeing the next page. Also, when \code{print.four.plots.per.page} is \code{TRUE}, the function won't 
-#'   return any plot objects as output. When \code{print.four.plots.per.page} is set to \code{FALSE}, 
+#'   before seeing the next page. Also, when \code{print.four.plots.per.page} is \code{TRUE}, the function won't
+#'   return any plot objects as output. When \code{print.four.plots.per.page} is set to \code{FALSE},
 #'   the function returns a list of ggplot objects, one element per plot.
-#' @param jj Numeric; controls \code{\link{jitter}} and allows you to control the 
-#'   degree of jitter in the contrast plots. \code{jj} is divided by 100 and passed as the \code{amount} 
-#'   parameter to \code{\link{jitter}}. 
+#' @param jj Numeric; controls \code{\link{jitter}} and allows you to control the
+#'   degree of jitter in the contrast plots. \code{jj} is divided by 100 and passed as the \code{amount}
+#'   parameter to \code{\link{jitter}}.
 #' @param ... Optional arguments to/from other functions.
 #' @return If \code{print.four.plots.per.page} is set to \code{FALSE}, the function returns
 #'   a list of ggplot objects, one element per plot. That allows you to access any individual plot
-#'   or plots, then modify them as you wish (with ggplot2 commands, for example). 
+#'   or plots, then modify them as you wish (with ggplot2 commands, for example).
 #'   When \code{print.four.plots.per.page} is set to \code{TRUE}
-#'   (the default), the function prints four plots per page on a graphical device 
+#'   (the default), the function prints four plots per page on a graphical device
 #'   but returns \code{NULL}.
-#'   
-#'   The function also provides printed output: 
+#'
+#'   The function also provides printed output:
 #'   \item{Weighted Means}{Table showing the (weighted) means for positive
 #'      and negative coefficients for each (row) contrast, and for each row, the
 #'      difference between these means, and the standardized effect size in the
@@ -74,17 +74,17 @@
 #'      model analysis based on the R function \code{lm} (When effects are simple,
 #'      as in an equal n's power of 2 design, mean differences will generally
 #'      correspond to the linear regression coefficients as seen in the \code{lm}
-#'      summary results.)} 
+#'      summary results.)}
 #'   \item{Contrasts}{The contrast matrix you specified.}
 #'
-#' @author Brian A. Danielak \email{brian@@briandk.com}\cr 
+#' @author Brian A. Danielak \email{brian@@briandk.com}\cr
 #'   Robert M. Pruzek \email{RMPruzek@@yahoo.com}
 #'
 #' with contributions by:\cr
-#'   William E. J. Doane \email{wil@@drdoane.com}\cr 
-#'   James E. Helmreich \email{James.Helmreich@@Marist.edu}\cr 
+#'   William E. J. Doane \email{wil@@drdoane.com}\cr
+#'   James E. Helmreich \email{James.Helmreich@@Marist.edu}\cr
 #'   Jason Bryer \email{jason@@bryer.org}
-#' 
+#'
 #' @seealso \code{\link{granovagg.1w}},
 #'   \code{\link{granovagg.ds}}, \code{\link{granovaGG}}
 #' @keywords hplot
@@ -94,14 +94,14 @@
 #' @import gridExtra
 #' @import reshape2
 #' @export
-granovagg.contr <- function(data, 
-                            contrasts, 
+granovagg.contr <- function(data,
+                            contrasts,
                             ylab       = "default_y_label",
                             plot.theme = "theme_granova_contr",
                             print.four.plots.per.page = TRUE,
                             jj = 1,
                             ...
-                   ) 
+                   )
 {
 
   # Plots responses by contrasts.
@@ -117,15 +117,15 @@ granovagg.contr <- function(data,
     if (is.data.one.dimensional) {
       return(data)
     }
-    
+
     return(stack(as.data.frame(data))[, 1])
   }
-  
+
   GetDegreeOfJitter <- function(jj) {
     result <- jj / 100
     return(result)
   }
-  
+
   std.contr <- function(contrasts, tolerance = sqrt(.Machine$double.eps)^0.6) {
       if (!is.matrix(contrasts)) {
           contrasts <- as.matrix(contrasts)
@@ -141,10 +141,10 @@ granovagg.contr <- function(data,
           dg <- as.matrix(dg)
       }
       standardized.contrasts <- round(2 * contrasts %*% diag(1/dg), 3)
-      
+
       return(standardized.contrasts)
   }
-  
+
   indic <- function(xx) {
              mm <- matrix(0, length(xx), length(unique(xx)))
              indx <- ifelse(xx == col(mm), 1, 0)
@@ -152,7 +152,7 @@ granovagg.contr <- function(data,
   }
 
   AdaptVariablesFromGranovaComputations <- function () {
-    
+
     response            <- FormatResponseData(data)
     contrasts           <- as.matrix(contrasts)
     number.of.groups    <- nrow(contrasts)
@@ -161,7 +161,7 @@ granovagg.contr <- function(data,
     indicator.matrix    <- indic(group.identifiers)
     indicated.contrasts <- indicator.matrix %*% contrasts
     standardized.contrasts <- std.contr(indicated.contrasts)
-    
+
     return(
         list(
           response                      = response,
@@ -177,30 +177,30 @@ granovagg.contr <- function(data,
   GetContrastPlotData <- function (ctr) {
     return(
       lapply(
-        X         = 1:ctr$number.of.contrasts, 
+        X         = 1:ctr$number.of.contrasts,
         FUN       = ExtractDataForPlot,
         contrasts = ctr$scaled.standardized.contrasts,
         response  = ctr$response
       )
-    ) 
+    )
   }
 
   GetLinearModel <- function(ctr) {
     Contrast <- ctr$scaled.standardized.contrasts
     Response <- ctr$response
-    
+
     return(lm(Response ~ Contrast))
   }
-  
+
   ExtractDataForPlot <- function (contrasts, response, index) {
       non.zero.indicators <- contrasts[, index] != 0
       x.values <- contrasts[, index][non.zero.indicators]
-      y.values <- response[non.zero.indicators]   
+      y.values <- response[non.zero.indicators]
       raw.data <- data.frame(x.values, y.values)
-  
+
     return(
         list(
-          raw.data     = raw.data, 
+          raw.data     = raw.data,
           summary.data = GetSummary(raw.data)
         )
     )
@@ -214,7 +214,7 @@ granovagg.contr <- function(data,
       )
     )
   }
-  
+
   GetContrastPlots <- function (ctr) {
     return(
       lapply(
@@ -224,8 +224,8 @@ granovagg.contr <- function(data,
       )
     )
   }
-  
-  ComposeContrastPlot <- function(plot.data, index) {    
+
+  ComposeContrastPlot <- function(plot.data, index) {
     p <- ggplot()
     p <- p + MeanResponse(plot.data[[index]]$raw.data$y.values)
     p <- p + JitteredResponsesByContrast(plot.data[[index]]$raw.data)
@@ -235,14 +235,14 @@ granovagg.contr <- function(data,
     p <- p + ContrastPlotTitle(ctr, index)
     p <- p + ContrastPlotXLabel(ctr, index)
     p <- p + YLabel()
-        
+
     return(p)
   }
-  
+
   MeanResponse <- function(response) {
     return(
       geom_hline(
-        aes_string(yintercept = mean(response)), 
+        aes_string(yintercept = mean(response)),
         color = brewer.pal(8, "Set1")[1],
         data  = as.data.frame(data),
         alpha = 0.5,
@@ -250,12 +250,12 @@ granovagg.contr <- function(data,
       )
     )
   }
-  
+
   JitteredResponsesByContrast <- function (data) {
     return(
       geom_point(
                aes(
-                 x = x.values, 
+                 x = x.values,
                  y = y.values
                ),
                data     = data,
@@ -263,12 +263,12 @@ granovagg.contr <- function(data,
       )
     )
   }
-  
+
   EffectsOfContrasts <- function(data) {
     return(
       geom_point(
                aes(
-                 x = contrasts, 
+                 x = contrasts,
                  y = responses
                ),
                data  = data,
@@ -278,12 +278,12 @@ granovagg.contr <- function(data,
       )
     )
   }
-  
+
   ConnectEffectMeans <- function(data) {
     return(
       geom_line(
                aes(
-                 x = contrasts, 
+                 x = contrasts,
                  y = responses
                ),
                data  = data,
@@ -292,28 +292,29 @@ granovagg.contr <- function(data,
       )
     )
   }
-  
+
   ContrastPlotTitle <- function(ctr, index) {
+    plot.title <- paste("Coefficients vs. Response\n", GetContrastName(ctr$contrast.matrix, index))
     return(
-        opts(title = paste("Coefficients vs. Response\n", GetContrastName(ctr$contrast.matrix, index)))
+        ggtitle(plot.title)
     )
   }
-  
+
   ContrastPlotXLabel <- function(ctr, index) {
     return(
         xlab(paste(GetContrastName(ctr$contrast.matrix, index)))
     )
   }
-  
+
   YLabel <- function() {
     result <- ylab
     if (ylab == "default_y_label") {
       result <- "Outcome (Response)"
     }
-    
+
     return(ylab(paste(result)))
   }
-  
+
   GetSummaryPlotData <- function(ctr) {
     raw.data <- as.data.frame(
                    matrix(ctr$response, ncol = ctr$number.of.groups)
@@ -322,23 +323,23 @@ granovagg.contr <- function(data,
     raw.data <- melt(raw.data)
     raw.data$variable <- as.numeric(raw.data$variable)
     summary.data <- GetGroupSummary(raw.data)
-    
+
     return(list(
                 raw.data     = raw.data,
                 summary.data = summary.data
           )
-    )                   
+    )
   }
-  
+
   RenameSummaryColumnNames <- function(data) {
     colnames(data) <- sapply(
-                        1:ncol(data), 
+                        1:ncol(data),
                         function(index) {paste(index)}
                       )
-                      
+
     return(data)
   }
-  
+
   GetGroupSummary <- function(data) {
     output <- ddply(data, .(variable), summarise,
                 group      = unique(variable),
@@ -348,8 +349,8 @@ granovagg.contr <- function(data,
     output <- transform(output, pooled.standard.deviation = mean(standard.deviation^2)^0.5)
     return(subset(output, select = -variable))
   }
-  
-  ComposeSummaryPlot <- function(plot.data) {    
+
+  ComposeSummaryPlot <- function(plot.data) {
     p <- ggplot()
     p <- p + MeanResponse(plot.data$raw.data$value)
     p <- p + RawScoresByGroup(plot.data$raw.data)
@@ -361,12 +362,12 @@ granovagg.contr <- function(data,
     p <- p + YLabel()
     return(p)
   }
-  
+
   RawScoresByGroup <- function(data) {
     return(
       geom_point(
                aes(
-                 x = as.factor(variable), 
+                 x = as.factor(variable),
                  y = value
                ),
                data = data,
@@ -374,12 +375,12 @@ granovagg.contr <- function(data,
       )
     )
   }
-  
+
   MeansByGroup <- function(data) {
     return(
       geom_point(
                aes(
-                 x = group, 
+                 x = group,
                  y = group.mean
                ),
                data  = data,
@@ -389,12 +390,12 @@ granovagg.contr <- function(data,
       )
     )
   }
-  
+
   ConnectGroupResponseMeans <- function(data) {
     return(
       geom_line(
                aes(
-                 x = group, 
+                 x = group,
                  y = group.mean
                ),
                data  = data,
@@ -403,47 +404,48 @@ granovagg.contr <- function(data,
       )
     )
   }
-  
+
   GroupSummaryPlotTitle <- function(ctr) {
+    plot.title <- paste("Responses for all groups\n", "each n = ", ctr$responses.per.group)
     return(
-      opts(title = paste("Responses for all groups\n", "each n = ", ctr$responses.per.group))
+      ggtitle(plot.title)
     )
   }
-  
+
   GroupSummaryXLabel <- function() {
     return(xlab("Group Indicator"))
   }
 
   CollateOutputPlots <- function(ctr) {
     output <- list(NULL)
-    
+
     for (i in 1:ctr$number.of.contrasts) {
       output[[i]] <- ctr$contrast.plots[[i]]
     }
-    output[[ctr$number.of.contrasts + 1]] <- ctr$summary.plot  
-    
+    output[[ctr$number.of.contrasts + 1]] <- ctr$summary.plot
+
     return(output)
   }
-  
+
   OptionalPlotPrinting <- function(output) {
     if (print.four.plots.per.page) {
       LayoutFourPlotsPerPage(output)
     }
   }
-  
+
   PrintOutput <- function() {
     PrintLinearModelSummary(ctr$linear.model)
     PrintSummaryDataByContrast(ctr)
     PrintSummaryDataByGroup(ctr)
     PrintContrasts(ctr)
   }
-  
+
   PrintLinearModelSummary <- function(model) {
     model.summary <- summary(model)
     message("\nLinear Model Summary")
     print(model.summary)
   }
-  
+
   GetSummaryDataByContrast <- function(x, pooled.standard.deviation) {
     ExtractData <- function(x) {
       summary.data <- x$summary.data
@@ -457,31 +459,31 @@ granovagg.contr <- function(data,
     output <- ForceRowNamesToBeContrastNumbers(output)
     return(output)
   }
-  
+
   ForceRowNamesToBeContrastNumbers <- function(x) {
     dimnames(x)[[1]] <- sapply(1:(dim(x)[[1]]), function(x) {paste("Contrast", x, sep="")})
-    
+
     return(x)
   }
-  
+
   PrintSummaryDataByContrast <- function(ctr) {
     message("\n(Weighted) means, mean differences, and standardized effect size")
     print(
       GetSummaryDataByContrast(ctr$contrast.plot.data, ctr$summary.plot.data$summary.data$pooled.standard.deviation[1]), digits = 3)
   }
-  
+
   PrintSummaryDataByGroup <- function(ctr) {
     message("\nSummary statistics by group")
     print(ctr$summary.plot.data$summary.data, digits = 4)
   }
-  
+
   PrintContrasts <- function(ctr) {
     message("\nThe contrasts you specified")
     print(ctr$contrast.matrix, digits = 3)
   }
-  
+
   GetOutput <- function(ctr) {
-    four.plot.message <- paste("Since you elected to print four plots per page\n", 
+    four.plot.message <- paste("Since you elected to print four plots per page\n",
                                "granovagg.contr won't return any plot objects.", sep = ""
                          )
     if (print.four.plots.per.page) {
@@ -489,13 +491,13 @@ granovagg.contr <- function(data,
       LayoutFourPlotsPerPage(ctr$output)
       output <- NULL
     }
-    
+
     else {
       output <- ctr$output
     }
     return(output)
   }
-  
+
   ctr                        <- AdaptVariablesFromGranovaComputations()
   ctr$linear.model           <- GetLinearModel(ctr)
   ctr$contrast.plot.data     <- GetContrastPlotData(ctr)
@@ -504,7 +506,7 @@ granovagg.contr <- function(data,
   ctr$summary.plot           <- ComposeSummaryPlot(ctr$summary.plot.data)
   ctr$output                 <- CollateOutputPlots(ctr)
   PrintOutput()
-    
+
   return(GetOutput(ctr))
 
 }
