@@ -1,9 +1,9 @@
 #' Elemental Graphic for Display of Dependent Sample Data
-#' 
+#'
 #' Plots dependent sample data beginning from a scatterplot for the X,Y pairs;
 #' proceeds to display difference scores as point projections; also X and Y
 #' means, as well as the mean of the difference scores.
-#' 
+#'
 #' Paired X and Y values are plotted as scatterplot. The identity reference line
 #' (for Y = X) is drawn. Parallel projections of data points to (a lower-left)
 #' line segment show how each point relates to its X-Y = D difference;
@@ -20,8 +20,8 @@
 #' Because all data points are plotted relative to the identity line, and
 #' summary results are shown graphically, clusters, data trends, outliers, and
 #' possible uses of transformations are readily seen, possibly to be
-#' accommodated. 
-#' 
+#' accommodated.
+#'
 #' In summary, the graphic shows all initial data points relative to the
 #' identity line, adds projections (to the 'north' and 'east') showing the
 #' marginal distributions of X and Y, as well as projections to the 'southwest'
@@ -30,7 +30,7 @@
 #' population mean difference score is also shown. Summary statistics are
 #' printed as side effects of running the function for the dependent sample
 #' analysis.
-#' 
+#'
 #' @param data is an n X 2 dataframe or matrix. First column defines X
 #'   (intially for horzontal axis), the second defines Y.
 #' @param main optional main title (as character); can be supplied by user. The default value is
@@ -40,30 +40,29 @@
 #'   defined, axis labels are taken from colnames of data.
 #' @param ylab optional label (as character) for vertical axis. If not
 #'   defined, axis labels are taken from colnames of data.
-#' @param conf.level The confidence level at which to perform a dependent sample t-test. 
+#' @param conf.level The confidence level at which to perform a dependent sample t-test.
 #'   Defaults to \code{0.95} (95\% Confidence)
 #' @param plot.theme argument indicating a ggplot2 theme to apply to the
 #'   graphic; defaults to a customized theme created for the dependent sample graphic
-#' @param northeast.padding (numeric) extends axes toward lower left, 
+#' @param northeast.padding (numeric) extends axes toward lower left,
 #'   effectively moving data points to the southwest. Defaults to zero padding.
 #' @param southwest.padding (numeric) extends axes toward upper right,
 #'   effectively moving data points to the southwest. Defaults to zero padding.
-#'   Making both southwest and northeast padding smaller moves points farther apart, 
+#'   Making both southwest and northeast padding smaller moves points farther apart,
 #'   while making both larger moves data points closer together.
 #' @param ... Optional arguments to/from other functions
-#' @return Returns a plot object of class \code{ggplot}. 
+#' @return Returns a plot object of class \code{ggplot}.
 #'
-#' @author Brian A. Danielak \email{brian@@briandk.com}\cr 
+#' @author Brian A. Danielak \email{brian@@briandk.com}\cr
 #'   Robert M. Pruzek \email{RMPruzek@@yahoo.com}
 #'
 #' with contributions by:\cr
-#'   William E. J. Doane \email{wil@@drdoane.com}\cr 
-#'   James E. Helmreich \email{James.Helmreich@@Marist.edu}\cr 
+#'   William E. J. Doane \email{wil@@drdoane.com}\cr
+#'   James E. Helmreich \email{James.Helmreich@@Marist.edu}\cr
 #'   Jason Bryer \email{jason@@bryer.org}
 #'
 #' @seealso \code{\link{granovagg.1w}},
-#'   \code{\link{granovagg.ds}}, \code{\link{granovaGG}},
-#'   \code{\link{geom_rug_alt}}
+#'   \code{\link{granovagg.ds}}, \code{\link{granovaGG}}
 #'
 #' @example demo/granovagg.ds.R
 #' @export
@@ -71,7 +70,7 @@
 #' @references Wickham, H. (2009). Ggplot2: Elegant Graphics for Data Analysis. New York: Springer.
 #' @references Wilkinson, L. (1999). The Grammar of Graphics. Statistics and computing. New York: Springer.
 granovagg.ds <- function(data       = NULL,
-                         revc       = FALSE, 
+                         revc       = FALSE,
                          main       = "default_granova_title",
                          xlab       = NULL,
                          ylab       = NULL,
@@ -80,10 +79,10 @@ granovagg.ds <- function(data       = NULL,
                          northeast.padding = 0,
                          southwest.padding = 0,
                          ...
-                ) 
+                )
 
 {
-  
+
   GetData <- function(data) {
     data <- CheckData(data)
     data <- ReverseXAndY(data)
@@ -91,13 +90,13 @@ granovagg.ds <- function(data       = NULL,
     data <- EnsureDataIsADataFrame(data)
     return(data)
   }
-  
+
   CheckData <- function(data) {
     IsDataNull(data)
     IsDataInTwoColumnFormat(data)
     return(data)
   }
-  
+
   ReverseXAndY <- function(data) {
     output <- data
     if (revc) {
@@ -107,7 +106,7 @@ granovagg.ds <- function(data       = NULL,
     }
     return(output)
   }
-  
+
   IsDataNull <- function(data) {
     if (is.null(length(data))) {
       stop("It looks like you didn't pass any data to granovagg.ds")
@@ -119,12 +118,12 @@ granovagg.ds <- function(data       = NULL,
     if (is.null(dim(data))) {
       stop(message)
     }
-    
+
     if (dim(data)[2] != 2) {
       stop(message)
     }
   }
-  
+
   EnsureDataIsADataFrame <- function(data) {
     output <- data
     if (!is.data.frame(data)) {
@@ -132,16 +131,16 @@ granovagg.ds <- function(data       = NULL,
     }
     return(output)
   }
-  
+
   EnsureDataHasColumnNames <- function(data) {
     output <- data
     if (is.null(colnames(data))) {
       colnames(data) <- c("x", "y")
     }
-    
+
     return(data)
   }
-  
+
   GetXs <- function(data) {
     return(data[, 1])
   }
@@ -153,16 +152,16 @@ granovagg.ds <- function(data       = NULL,
   GetEffect <- function(dsp) {
     return(GetXs(dsp$data) - GetYs(dsp$data))
   }
-  
+
   GetTtest <- function(data, conf.level) {
-    return(t.test(data[, 1], 
-                  data[, 2], 
+    return(t.test(data[, 1],
+                  data[, 2],
                   paired     = TRUE,
                   conf.level = conf.level
                  )
           )
   }
-  
+
   GetStats <- function(dsp, conf.level) {
     ttest <- GetTtest(dsp$data, conf.level)
     return(data.frame(lower.treatment.effect = as.numeric(ttest$conf.int[2]),
@@ -172,10 +171,10 @@ granovagg.ds <- function(data       = NULL,
                      )
           )
   }
-  
+
   GetGraphicsParams <- function(dsp) {
     .aggregate.data.range  <- c(range(GetXs(dsp$data)), range(GetYs(dsp$data)))
-    .extrema               <- c(max(.aggregate.data.range), min(.aggregate.data.range))    
+    .extrema               <- c(max(.aggregate.data.range), min(.aggregate.data.range))
     .square.data.range     <- max(.extrema) - min(.extrema)
     .southwest.padding     <- (65/100) * .square.data.range
     .northeast.padding     <- (15/100) * .square.data.range
@@ -185,20 +184,20 @@ granovagg.ds <- function(data       = NULL,
     .center                <- mean(.bounds)
     .crossbow.anchor       <- mean(.bounds) + min(.bounds)
     .shadow.offset         <- (1/100)*.square.data.range
-  
-    return(list(square.data.range = .square.data.range,    
-                bounds            = .bounds,  
+
+    return(list(square.data.range = .square.data.range,
+                bounds            = .bounds,
                 shadow.offset     = .shadow.offset,
                 anchor            = .crossbow.anchor,
                 point.size        = I(2.5),
-                mean.line.size    = I(1/2)      
+                mean.line.size    = I(1/2)
                )
           )
   }
-  
+
   GetShadows <- function(dsp) {
-    x.shadow <- (dsp$effect / 2) + 
-                (3 * dsp$params$bounds[1] + dsp$params$bounds[2]) / 4 + 
+    x.shadow <- (dsp$effect / 2) +
+                (3 * dsp$params$bounds[1] + dsp$params$bounds[2]) / 4 +
                 (4 * dsp$params$shadow.offset)
     y.shadow <- x.shadow - dsp$effect
     return(data.frame(x.shadow, y.shadow))
@@ -210,9 +209,9 @@ granovagg.ds <- function(data       = NULL,
                       x.end = max(dsp$shadows$x.shadow) - (2 * dsp$params$shadow.offset),
                       y.end = min(dsp$shadows$y.shadow) - (2 * dsp$params$shadow.offset)
                      )
-          )  
+          )
   }
-  
+
   GetCIBand <- function(dsp) {
     return(data.frame(x.end = ((dsp$params$anchor + dsp$stats$lower.treatment.effect) / 2) - 3 * (dsp$params$shadow.offset),
                       y.end = ((dsp$params$anchor - dsp$stats$lower.treatment.effect) / 2) - 3 * (dsp$params$shadow.offset),
@@ -221,9 +220,9 @@ granovagg.ds <- function(data       = NULL,
                       color = factor(paste(100 * conf.level, "% CI", " (t = ", round(dsp$stats$t.statistic, digits = 2), ")", sep =""))
                      )
           )
-    
+
   }
-  
+
   GetTreatmentLine <- function(dsp) {
     return(data.frame(intercept = -dsp$stats$mean.treatment.effect,
                       slope     = 1,
@@ -246,16 +245,16 @@ granovagg.ds <- function(data       = NULL,
                )
     return(c(minimum - dsp$params$shadow.offset, max(dsp$params$bounds)))
   }
-  
+
   GetTrails <- function(dsp) {
-    return(data.frame(x.trail.start = GetXs(dsp$data), 
+    return(data.frame(x.trail.start = GetXs(dsp$data),
                       y.trail.start = GetYs(dsp$data),
-                      x.trail.end   = GetXs(dsp$shadow), 
+                      x.trail.end   = GetXs(dsp$shadow),
                       y.trail.end   = GetYs(dsp$shadow)
                      )
           )
   }
-  
+
   GetColors <- function(dsp) {
     return(list(treatment.line = "#542570",
                 rugplot        = "black",
@@ -263,17 +262,17 @@ granovagg.ds <- function(data       = NULL,
                 CIBand         = "#33A02C",
                 crossbow       = "#377EB8"
                )
-          )         
+          )
   }
-  
+
   PrintSummary <- function(dsp) {
     summary <- GetPrintedSummary(dsp)
     summary <- RenamePrintedSummaryRows(summary)
     summary <- round(summary, digits = 3)
-    
+
     print(summary)
   }
-  
+
   GetPrintedSummary <- function(dsp) {
     n <- dim(dsp$data)[1]
     mean.1 <- mean(dsp$data[, 1])
@@ -288,30 +287,30 @@ granovagg.ds <- function(data       = NULL,
     t.value <- dsp$t.test$statistic
     degrees.of.freedom <- dsp$t.test$parameter
     p.value <- dsp$t.test$p.value
-    
-    return(matrix(c(n, 
-                    mean.1, 
-                    mean.2, 
-                    mean.d, 
-                    standard.deviation.d, 
-                    effect.size, 
-                    r.xy, 
-                    r.x.plus.y.d, 
-                    lower.treatment.confidence, 
-                    upper.treatment.confidence, 
-                    t.value, 
-                    degrees.of.freedom, 
+
+    return(matrix(c(n,
+                    mean.1,
+                    mean.2,
+                    mean.d,
+                    standard.deviation.d,
+                    effect.size,
+                    r.xy,
+                    r.x.plus.y.d,
+                    lower.treatment.confidence,
+                    upper.treatment.confidence,
+                    t.value,
+                    degrees.of.freedom,
                     p.value
-                  ), 
+                  ),
                  ncol = 1
            )
     )
   }
-  
+
   RenamePrintedSummaryRows <- function(summary) {
     dimnames(summary) <- list(
-                           c("n", 
-                             paste(colnames(dsp$data)[1], "mean"), 
+                           c("n",
+                             paste(colnames(dsp$data)[1], "mean"),
                              paste(colnames(dsp$data)[2], "mean"),
                              paste("mean(D = ", colnames(dsp$data)[1], " - ", colnames(dsp$data)[2], ")",  sep = ""),
                              paste("SD(D)"),
@@ -324,10 +323,10 @@ granovagg.ds <- function(data       = NULL,
                              paste("df.t"),
                              paste("p-value (t-statistic)")
                            ), "Summary Statistics")
-                         
+
     return(summary)
   }
-  
+
   dsp                <- list(data = GetData(data))
   dsp$effect         <- GetEffect(dsp)
   dsp$stats          <- GetStats(dsp, conf.level)
@@ -342,23 +341,23 @@ granovagg.ds <- function(data       = NULL,
   dsp$trails         <- GetTrails(dsp)
   dsp$colors         <- GetColors(dsp)
   PrintSummary(dsp)
-    
-  
+
+
 
   # Because of the way ggplot2 creates plot objects, layers can be
   # added to a plot p simply by calling "p <- p + newLayer"
 
-  
+
   InitializeGgplot <- function(dsp) {
     return(
       ggplot(
-        aes_string(x = dsp$data[1], 
+        aes_string(x = dsp$data[1],
                    y = dsp$data[2]
         ), data = dsp$data
       )
     )
   }
-    
+
   TreatmentLine <- function(dsp) {
     return(geom_abline(aes(intercept = intercept,
                            slope     = slope,
@@ -377,7 +376,7 @@ granovagg.ds <- function(data       = NULL,
   }
 
   IdentityLine <- function() {
-    return(geom_abline(slope     = 1, 
+    return(geom_abline(slope     = 1,
                        intercept = 0,
                        alpha     = 0.75,
                        size      = 1
@@ -392,26 +391,29 @@ granovagg.ds <- function(data       = NULL,
   ScaleY <- function(dsp) {
     return(scale_y_continuous(limits = dsp$params$bounds))
   }
-  
+
   PadViewingWindow <- function(params) {
     ne.offset = params$square.data.range * southwest.padding
     sw.offset = params$square.data.range * northeast.padding
     padded.window = c(params$bounds[1] - sw.offset, params$bounds[2] + ne.offset)
-    
+
     return(
       coord_cartesian(xlim = padded.window,
                       ylim = padded.window
       )
     )
-  } 
+  }
 
   RugPlot <- function(dsp) {
-    return(geom_rug_alt(size  = I(1/2),
-                        alpha = I(1/3),
-                        color = dsp$colors$rugplot,
-                        data  = dsp$data
-                   )  
-          )
+    return(
+      geom_rug(
+        size  = I(1/2),
+        alpha = I(1/3),
+        color = dsp$colors$rugplot,
+        sides = "tr", # top and right sides
+        data  = dsp$data
+      )
+    )
   }
 
   XMeanLine <- function(dsp) {
@@ -420,19 +422,19 @@ granovagg.ds <- function(data       = NULL,
                       size       = dsp$params$mean.line.size,
                       linetype   = "dashed",
                       alpha      = I(1/2)
-                     ) 
+                     )
           )
   }
-  
+
   YMeanLine <- function(dsp)  {
     return(geom_hline(yintercept = mean(GetYs(dsp$data)),
                       color      = dsp$colors$mean.line,
                       size       = dsp$params$mean.line.size,
                       linetype   = "dashed",
                       alpha      = I(1/2)
-                     ) 
+                     )
           )
-    
+
   }
 
   Crossbow <- function(dsp) {
@@ -440,12 +442,12 @@ granovagg.ds <- function(data       = NULL,
                             y    = y,
                             xend = x.end,
                             yend = y.end
-                           ), 
+                           ),
                         size  = I(3/4),
                         alpha = I(3/4),
                         color = dsp$colors$crossbow,
                         data  = dsp$crossbow
-                       )  
+                       )
           )
   }
 
@@ -453,9 +455,9 @@ granovagg.ds <- function(data       = NULL,
     return(geom_segment(aes(x     = x,
                             y     = y,
                             xend  = x.end,
-                            yend  = y.end,                        
+                            yend  = y.end,
                             color = color
-                           ), 
+                           ),
                         size = I(2),
                         data = dsp$CIBand
                        )
@@ -466,10 +468,10 @@ granovagg.ds <- function(data       = NULL,
     return(geom_point(aes(x = x.shadow,
                           y = y.shadow
                          ),
-                      data  = dsp$shadow, 
+                      data  = dsp$shadow,
                       size  = dsp$params$point.size,
                       shape = 16,
-                      alpha = I(1/2) 
+                      alpha = I(1/2)
                      )
           )
   }
@@ -484,14 +486,14 @@ granovagg.ds <- function(data       = NULL,
                         size     = I(1/3),
                         color    = "black",
                         linetype = 1,
-                        alpha    = I(1/10)              
-                       ) 
+                        alpha    = I(1/10)
+                       )
           )
   }
 
   ColorScale <- function(dsp) {
     colors <- c(dsp$colors$treatment.line, dsp$colors$CIBand)
-  
+
     return(scale_color_manual(values = colors, name = ""))
   }
 
@@ -500,34 +502,36 @@ granovagg.ds <- function(data       = NULL,
     if(!is.null(xlab)) {
       result <- xlab
     }
-    
+
     return(xlab(result))
   }
-  
+
   YLabel <- function(dsp) {
     result <- colnames(dsp$data)[2]
     if(!is.null(ylab)) {
       result <- ylab
     }
-    
+
     return(ylab(result))
   }
-  
-  Title <- function() {
-    if (main == "default_granova_title") {
-      return(opts(title = "Dependent Sample Assessment Plot"))
-    }
-    
-    else {
-      return(opts(title = main))
+
+  Title <- function(main) {
+    output.title <- "Dependent Sample Assessment Plot"
+    if (main != "default_granova_title") {
+      output.title <- main
     }
+
+    return(
+      ggtitle(output.title)
+    )
+
   }
-  
+
   ForceCoordinateAxesToBeEqual <- function() {
     return(coord_fixed(ratio = 1))
   }
-  
-          
+
+
   p <- InitializeGgplot(dsp)
   p <- p + TreatmentLine(dsp)
   p <- p + XMeanLine(dsp) + YMeanLine(dsp)
@@ -543,7 +547,7 @@ granovagg.ds <- function(data       = NULL,
   p <- p + ScaleX(dsp) + ScaleY(dsp)
   p <- p + PadViewingWindow(dsp$params)
   p <- p + ForceCoordinateAxesToBeEqual()
-  p <- p + Title()
+  p <- p + Title(main)
   p <- p + XLabel(dsp)
   p <- p + YLabel(dsp)
 
